#
# spec file for package armadillo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname libarmadillo14
Name:           armadillo
Version:        14.0.1
Release:        1.1
Summary:        C++ matrix library with interfaces to LAPACK and ATLAS
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://arma.sourceforge.net/
Source:         https://sourceforge.net/projects/arma/files/%{name}-%{version}.tar.xz
Source2:        baselibs.conf
BuildRequires:  arpack-ng-devel
BuildRequires:  blas-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  lapack-devel
BuildRequires:  pkgconfig
BuildRequires:  superlu-devel >= 5.2

%description
Armadillo is a C++ linear algebra library (matrix maths).
Integer, floating point and complex numbers are supported,
as well as a subset of trigonometric and statistics functions.

%package     -n %{soname}
Summary:        C++ matrix library with interfaces to LAPACK and ATLAS
Group:          System/Libraries

%description -n %{soname}
Armadillo is a C++ linear algebra library (matrix maths).
Integer, floating point and complex numbers are supported,
as well as a subset of trigonometric and statistics functions.
Various matrix decompositions are provided through optional
integration with LAPACK and ATLAS libraries.
A delayed evaluation approach is employed (during compile time)
to combine several operations into one and reduce (or eliminate)
the need for temporaries. This is accomplished through recursive
templates and template meta-programming.

This package provides the shared libraries for armadillo.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
Armadillo is a C++ linear algebra library (matrix maths).
Integer, floating point and complex numbers are supported,
as well as a subset of trigonometric and statistics functions.

This package provides the documentation for armadillo.

%package        devel
Summary:        Development headers and documentation for the Armadillo C++ library
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}
Requires:       arpack-ng-devel
Requires:       blas-devel
Requires:       lapack-devel
Requires:       libstdc++-devel
Requires:       superlu-devel >= 4.3
Recommends:     %{name}-doc

%description    devel
Armadillo is a C++ linear algebra library (matrix maths).
Integer, floating point and complex numbers are supported,
as well as a subset of trigonometric and statistics functions.

This package contains files necessary for development using the
Armadillo C++ library. It contains header files, example programs,
and user documentation (reference guide).

%prep
%setup -q
#Convert DOS end-of-line to UNIX end-of-line
sed -i 's/\r$//' README.md
sed -i 's/\r$//' examples/README.txt
sed -i 's/\r$//' LICENSE.txt
sed -i 's/\r$//' NOTICE.txt
for i in `ls examples/*.cpp`; do sed -i 's/\r$//' $i; done

%build
%cmake -DBUILD_SMOKE_TEST:BOOL=ON
%cmake_build

%install
%cmake_install
rm -f examples/Makefile.cmake
rm -rf examples/example1_win64.*
rm -rf examples/example2_win64.*
rm -rf examples/lib_win64

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest

%post -n %{soname} -p /sbin/ldconfig
%postun -n %{soname} -p /sbin/ldconfig

%files -n %{soname}
%{_libdir}/*.so.*

%files doc
%doc armadillo_*.pdf
%doc NOTICE.txt README.md index.html examples/ docs.html
%license LICENSE.txt

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/armadillo
%{_includedir}/armadillo_bits/
%{_datadir}/Armadillo/

%changelog
* Mon Jul  8 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 14.0.1:
  * No release notes.
* Sat Jun 29 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 14.0.0:
  * C++14 is now the minimum recommended C++ standard.
  * Faster handling of compound expressions by as_scalar(),
    accu(), dot().
  * Faster interactions between sparse and dense matrices.
  * Expanded stddev() to handle sparse matrices.
  * Expanded relational operators to handle expressions between
    sparse matrices and scalars.
  * Added .as_dense() to obtain dense vector/matrix representation
    of any sparse matrix expression.
  * Updated physical constants to NIST 2022 CODATA values.
* Tue May 14 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.8.3:
  * No release notes.
* Sat May  4 2024 Atri Bhattacharya <badshah400@gmail.com>
- Drop pkgconfig file from baselibs.conf generated -devel package
  to avoid "have choice" issues for dependents arising from both
  armadillo-devel and armadillo-32bit-devel (for example)
  providing pkgconfig(armadillo).
* Wed Apr  3 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.8.2:
  * No release notes.
* Tue Mar 12 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.8.1:
  * No release notes.
* Sun Feb 11 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.8.0:
  * Faster detection of symmetric expressions by pinv() and
    rank().
  * Expanded shift() to handle sparse matrices.
  * Expanded conv_to for more flexible conversions between sparse
    and dense matrices.
  * Added cbrt().
  * More compact representation of integers when saving matrices
    in CSV format.
* Thu Dec 28 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.6.7:
  * No release notes.
* Wed Nov 22 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.6.6:
  * No release notes.
* Mon Oct 16 2023 Atri Bhattacharya <A.Bhattacharya@uliege.be>
- Update to version 12.6.5:
  * No release notes.
* Sat Sep 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.6.4:
  * No release notes.
* Sat Aug 26 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.6.2:
  * No release notes.
* Wed Aug  2 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.6.1:
  * No release notes.
* Fri Jul 21 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.6.0:
  * Faster multiplication of dense vectors by sparse matrices (and
    vice versa).
  * Faster eigs_sym() and eigs_gen().
  * Faster conv() and conv2() when using OpenMP.
  * More efficient move constructors in dense vector classes.
  * Added diags() and spdiags() for generating band matrices from
    set of vectors.
* Mon Jun 19 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.4.1:
  * No release notes.
* Sat Jun 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.4.0:
  * added norm2est() for finding fast estimates of matrix 2-norm
    (spectral norm).
  * added vecnorm() for obtaining the vector norm of each row or
    column of a matrix.
* Fri Apr 21 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.2.0:
  * More efficient use of FFTW3 by fft() and ifft().
  * Faster in-place element-wise multiplication of sparse matrices
    by dense matrices.
  * Added spsolve_factoriser class to allow reuse of sparse matrix
    factorisation for solving systems of linear equations.
* Tue Mar 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.0.1:
  * faster fft() and ifft() via optional use of FFTW3.
  * faster min() and max().
  * faster index_min() and index_max().
  * added .col_as_mat() and .row_as_mat() which return matrix
    representation of cube column and cube row.
  * added csv_opts::strict option to loading CSV files to
    interpret missing values as NaN.
  * added check_for_zeros option to form 4 of sparse matrix batch
    constructors.
  * inv() and inv_sympd() with options inv_opts::no_ugly or
    inv_opts::allow_approx now use a scaled threshold similar to
    pinv().
  * set_cout_stream() and set_cerr_stream() are now no-ops;
    instead use the options ARMA_WARN_LEVEL, or ARMA_COUT_STREAM,
    or ARMA_CERR_STREAM.
- Bump lib version 11 -> 12, update baselibs.conf file.
* Sun Feb 19 2023 Dirk Müller <dmueller@suse.com>
- use https for urls
* Tue Feb 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.4.4:
  * Undocumented bug fixes.
* Tue Jan 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.4.3:
  * Undocumented bug fixes.
- Update source URL.
* Mon Oct 31 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.4.2:
  * Undocumented bug fixes.
* Tue Sep 27 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.4.0:
  * extended pow() with various forms of element-wise power
    operations.
  * added find_nan() to find indices of NaN elements.
  * faster handling of compound expressions by sum().
* Fri Sep  9 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.2.4:
  * Undocumented bug fixes.
* Wed Jul 13 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.2.3:
  * Undocumented bug fixes.
* Fri Jul  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.2.2:
  * Undocumented bug fixes.
* Mon Jun 13 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.2.0:
  * Faster handling of sparse submatrix column views by norm(),
    accu(), nonzeros().
  * Extended randu() and randn() to allow specification of
    distribution parameters.
* Wed May 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 11.1.1:
  + Workaround for bugs in gcc 4.8.
* Fri May 13 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.1.0:
  * Added inv_opts::no_ugly option to inv() and inv_sympd() to
    disallow inverses of poorly conditioned matrices.
  * More efficient handling of rank-deficient matrices via
    inv_opts::allow_approx option in inv() and inv_sympd().
  * Better detection of rank deficient matrices by solve().
  * Faster handling of symmetric and diagonal matrices by cond().
* Mon Apr 18 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 11.0.1:
  * Added variants of inv() and inv_sympd() that provide reciprocal
    condition number
  * Expanded inv() and inv_sympd() with options inv_opts::tiny and
    inv_opts::allow_approx
  * stricter handling of singular matrices by inv() and inv_sympd()
  * stricter handling of non-sympd matrices by inv_sympd()
  * stricter handling of non-finite matrices by pinv()
  * more robust handling of rank deficient matrices by solve()
  * faster handling of diagonal matrices by rcond()
  * changed eigs_sym() and eigs_gen() to use higher quality RNG
  * quantile() and median() will now throw an exception if given
    matrices/vectors have NaN elements
* Tue Feb  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.8.2:
  * Bug fix release.
* Sat Jan 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.8.1:
  * Bug fix release.
* Tue Jan 11 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.8.0:
  * Faster handling of symmetric matrices by pinv() and rank().
  * Faster handling of diagonal matrices by inv_sympd(), pinv(),
    rank().
  * Expanded norm() to handle integer vectors and matrices.
  * Added datum::tau to replace 2pi.
* Fri Dec 31 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.7.6:
  * Undocumented bug fixes.
- Drop conditionals for obsolete openSUSE versions.
* Fri Dec 24 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.7.5:
  * Undocumented bug fixes.
* Fri Nov 12 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.7.3:
  * Undocumented bug fixes.
* Thu Oct 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.7.1:
  * Faster handling of submatrix views accessed by
    X.cols(first_col,last_col).
  * Faster handling of element-wise min() and max() in compound
    expressions.
  * Expanded solve() with solve_opts::force_approx option to force
    use of the approximate solver.
* Sat Aug  7 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.6.2:
  * No documented changes.
* Wed Jul 28 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.6.1:
  * No documented changes.
* Fri Jul 16 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.6.0:
  * Expanded chol() to optionally use pivoted decomposition.
  * Expanded vector, matrix and cube constructors to allow element
    initialisation via fill::value(scalar), eg. mat
    X(4,5,fill::value(123)).
  * Faster loading of CSV files when using OpenMP.
  * Added csv_opts::semicolon option to allow saving/loading of
    CSV files with semicolon (;) instead of comma (,) as the
    separator.
* Fri Jul  9 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 10.5.3
  * fix for handling sparse matrices with no elements
  * minor speedups
* Mon Jun 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.5.2:
  * Undocumented bug fixes.
* Thu Jun  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 10.5.1
  * Minor bug fixes
* Sun May 23 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.5.0:
  * Added .clamp() member function.
  * Expanded the standalone clamp() function to handle complex
    values.
  * More efficient use of OpenMP.
  * vector, matrix and cube constructors now initialise elements
    to zero by default; use the fill::none specifier, eg. mat
    X(4,5,fill::none), to disable element initialisation.
* Sat May  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.4.1:
  * Faster handling of triangular matrices by log_det().
  * Added log_det_sympd() for log determinant of symmetric
    positive matrices.
  * Added ARMA_WARN_LEVEL configuration option, to control the
    degree of emitted warning messages.
  * Reduced the default degree of warning messages, so that failed
    decompositions, failed saving/loading, etc, no longer emit
    warnings.
* Sat Mar 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.3.0:
  * faster handling of symmetric positive definite matrices by
    pinv()
  * expanded .save() / .load() for dense matrices to handle
    coord_ascii format
  * for out of bounds access, element accessors now throw the more
    nuanced std::out_of_range exception, instead of only
    std::logic_error
  * improved quality of random numbers
* Thu Mar  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.2.2 (no release notes).
* Tue Feb 16 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.2.1:
  - No changelog from upstream.
* Thu Jan 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Fix baselibs.conf.
* Sun Jan 17 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.2.0:
  * Faster handling of subcubes.
  * Added tgamma().
  * Added .brief_print() for abridged printing of matrices &
    cubes.
  * Expanded forms of trimatu() and trimatl() with diagonal
    specification to handle sparse matrices.
  * Expanded eigs_sym() and eigs_gen() with optional shift-invert
    mode.
* Fri Nov 13 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.1.2:
  * Bug-fix release, no changelog from upstream.
- Enable building smoke test and run test as part of %%check
  section.
* Sat Oct 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.1.1:
  * Bug-fix release, no changelog from upstream.
* Wed Oct 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 10.1.0:
  * C++11 is now the minimum required C++ standard.
  * Faster handling of compound expressions by trimatu() and
    trimatl().
  * Faster sparse matrix addition, subtraction and element-wise
    multiplication.
  * Expanded sparse submatrix views to handle the non-contiguous
    form of X.cols(vector_of_column_indices).
  * Expanded eigs_sym() and eigs_gen() with optional fine-grained
    parameters (subspace dimension, number of iterations,
    eigenvalues closest to specified value).
- Fix an additional EOF encoding issue introduced in new release.
- Update shared lib name in keeping with so version update.
- Update baselibs.conf file for so version change.
* Sun Sep  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.900.3:
  * Bug-fix release, no changelog from upstream.
* Wed Jul 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.900.2:
  * Bug-fix release, no changelog from upstream.
* Tue Jun  9 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.900.1:
  * Faster solve() for under/over-determined systems.
  * Faster eig_gen() and eig_pair() for large matrices.
  * Expanded eig_gen() and eig_pair() to optionally provide left
    and right eigenvectors.
- Use cmake macros for configuring, building, and installing.
- Run spec-cleaner for minor cleanups.
* Sun May 17 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.880.1:
  * Expanded qr() to optionally use pivoted decomposition.
  * Updated physical constants to NIST 2018 CODATA values.
  * Added ARMA_DONT_USE_CXX11_MUTEX confguration option to disable
    use of std::mutex.
* Fri May  8 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.870.2:
  * Faster handling of matrix multiplication expressions by
    diagvec() and diagmat().
  * Added trimatu_ind() and trimatl_ind().
  * More consistent detection of sparse vector expressions.
* Mon Apr 13 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.860.2:
  * added powmat().
  * faster access to columns in sparse submatrix views.
  * faster handling of relational expressions by accu().
  * faster handling of sympd matrices by expmat(), logmat(),
    sqrtmat().
  * workaround for save/load issues with HDF5 v1.12.
* Thu Feb 20 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.850.1:
  * faster handling of compound expressions by diagmat().
  * expanded .save() and .load() to handle CSV files with headers
    via csv_name(filename,header) specification.
  * added log_normpdf().
  * added .is_zero().
  * added quantile().
* Sat Jan  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.800.3:
  * Minor bug fixes.
* Wed Oct 30 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.800.1:
  * Faster solve() in default operation; iterative refinement is
    no longer applied by default; use solve_opts::refine to
    explicitly enable refinement.
  * Faster expmat().
  * Faster handling of triangular matrices by rcond().
  * Added .front() and .back().
  * Added .is_trimatu() and .is_trimatl().
  * Added .is_diagmat().
* Thu Sep  5 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.700.2:
  * Faster handling of cubes by vectorise().
  * Faster handling of sparse matrices by nonzeros().
  * Faster row-wise index_min() and index_max().
  * Expanded join_rows() and join_cols() to handle joining up to 4
    matrices.
  * Expanded .save() and .load() to allow storing sparse matrices
    in CSV format.
  * Added randperm() to generate a vector with random permutation
    of a sequence of integers.
* Tue Jul 16 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.600.4:
  * faster handling of sparse submatrices.
  * faster handling of sparse diagonal views.
  * faster handling of sparse matrices by symmatu() and symmatl().
  * faster handling of sparse matrices by join_cols().
  * expanded clamp() to handle sparse matrices.
  * added .clean() to replace elements below a threshold with
    zeros; can be used to sparsify matrices.
* Tue Jun 25 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.500.2:
  * expanded solve() with solve_opts::likely_sympd to indicate
    that the given matrix is likely positive definite
  * more robust automatic detection of positive definite matrices
    by solve() and inv()
  * faster handling of sparse submatrices
  * expanded eigs_sym() to print a warning if the given matrix is
    not symmetric
  * extended LAPACK function prototypes to follow Fortran passing
    conventions for so-called "hidden arguments", in order to
    address GCC Bug 90329;
  * to use previous LAPACK function prototypes without the "hidden
    arguments", #define ARMA_DONT_USE_FORTRAN_HIDDEN_ARGS before
    [#]include <armadillo>
* Sat May 18 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.400.3:
  + Faster cov() and cor()
  + Added .as_col() and .as_row()
  + Expanded .shed_rows() / .shed_cols() / .shed_slices() to
    remove rows/columns/slices specified in a vector
  + Expanded vectorise() to handle sparse matrices
  + Expanded element-wise versions of max() and min() to handle
    sparse matrices
  + Optimised handling of sparse matrix expressions: sparse %%
    (sparse +- scalar) and sparse / (sparse +- scalar)
  + Expanded eig_sym(), chol(), expmat_sym(), logmat_sympd(),
    sqrtmat_sympd(), inv_sympd() to print a warning if the given
    matrix is not symmetric
  + More consistent detection of vector expressions
* Fri Apr 12 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.300.2:
  + faster handling of compound complex matrix expressions by
    trace().
  + more efficient handling of element access for inplace
    modifications in sparse matrices.
  + added .is_sympd() to check whether a matrix is
    symmetric/hermitian positive definite.
  + added interp2() for 2D data interpolation.
  + added expm1() and log1p().
  + expanded .is_sorted() with options "strictascend" and
    "strictdescend".
  + expanded eig_gen() to optionally perform balancing prior to
    decomposition.
* Fri Mar 15 2019 badshah400@gmail.com
- Update to version 9.200.8:
  + Misc bug fixes.
* Fri Jan 25 2019 badshah400@gmail.com
- Update to version 9.200.7:
  + Misc bug fixes.
* Thu Nov 15 2018 badshah400@gmail.com
- Update to version 9.200.4:
  + Faster handling of symmetric positive definite matrices by
    rcond().
  + Faster transpose of matrices with size ≥ 512x512.
  + Faster handling of compound sparse matrix expressions by
    accu(), diagmat(), trace().
  + Faster handling of sparse matrices by join_rows().
  + Added sinc().
  + Expanded sign() to handle scalar arguments.
  + Expanded operators (*, %%, +, −) to handle sparse matrices with
    differing element types (eg. multiplication of complex matrix
    by real matrix).
  + Expanded conv_to() to allow conversion between sparse matrices
    with differing element types.
  + Expanded solve() to optionally allow keeping solutions of
    systems singular to working precision.
* Thu Aug 16 2018 badshah400@gmail.com
- Update to version 9.100.5:
  + Faster handling of symmetric/hermitian positive definite
    matrices by solve().
  + Faster handling of inv_sympd() in compound expressions.
  + Added .is_symmetric().
  + Added .is_hermitian().
  + Expanded spsolve() to optionally allow keeping solutions of
    systems singular to working precision.
  + New configuration options ARMA_OPTIMISE_SOLVE_BAND and
    ARMA_OPTIMISE_SOLVE_SYMPD.
  + Smarter use of the element cache in sparse matrices.
- Pass a more robust regexp to sed for fixing end-of-line encoding
  changes.
- Update shlib package name in keeping with upstream versioning.
- Use %%%%license instead of %%%%doc to install license file.
* Wed May 16 2018 badshah400@gmail.com
- Update to version 8.500.1:
  + Faster handling of sparse matrices by kron() and repmat().
  + Faster transpose of sparse matrices.
  + Faster element access in sparse matrices.
  + Faster row iterators for sparse matrices.
  + Faster handling of compound expressions by trace().
  + More efficient handling of aliasing in submatrix views.
  + Expanded normalise() to handle sparse matrices.
  + Expanded .transform() and .for_each() to handle sparse
    matrices.
  + Added reverse() for reversing order of elements.
  + Added repelem() for replicating elements.
  + Added roots() for finding the roots of a polynomial.
* Wed Feb 21 2018 badshah400@gmail.com
- Update to version 8.400.0:
  + Faster handling of sparse matrices by repmat()
  + Faster loading of CSV files
  + Expanded kron() to handle sparse matrices
  + Expanded index_min() and index_max() to handle cubes
  + Expanded randi(), randu(), randn(), randg() to output single
    scalars
  + Added submatrix & subcube iterators
  + Added normcdf()
  + Added mvnrnd()
  + Added chi2rnd()
  + Added wishrnd() and iwishrnd()
* Tue Jan  9 2018 badshah400@gmail.com
- Update to version 8.300.3:
  + Misc bug fixes.
* Mon Dec 18 2017 badshah400@gmail.com
- Update to version 8.300.2:
  + Misc bug fixes.
* Wed Nov 22 2017 badshah400@gmail.com
- Update to version 8.300.0:
  + Faster handling of band matrices by solve().
  + Faster handling of band matrices by chol().
  + Faster randg() when using OpenMP.
  + Added normpdf().
  + Expanded .save() to allow appending new datasets to existing
    HDF5 files.
* Sun Nov  5 2017 badshah400@gmail.com
- Update to version 8.200.2:
  + Misc bug fixes.
* Wed Oct 18 2017 badshah400@gmail.com
- Update to version 8.200.1:
  + Misc bug fixes.
* Sun Oct 15 2017 badshah400@gmail.com
- Update to version 8.200.0:
  + Added intersect() for finding common elements in two
    vectors/matrices.
  + Expanded affmul() to handle non-square matrices.
* Tue Sep 12 2017 badshah400@gmail.com
- Update to version 8.100.1:
  + Misc bug fixes.
* Tue Sep  5 2017 jengelh@inai.de
- Trim descriptions, keeping the full description just for the
  one that is installed most often (libarmadillo8).
  Ensure neutrality of descriptions.
* Fri Sep  1 2017 badshah400@gmail.com
- Update to version 8.100.0:
  + Faster incremental construction of sparse matrices via element
    access operators
  + Faster diagonal views in sparse matrices
  + Expanded SpMat to save/load sparse matrices in coord format
  + Expanded .save()/.load() to allow specification of datasets
    within HDF5 files
  + Added affmul() to simplify application of affine
    transformations
  + Warnings and errors are now printed by default to the
    std::cerr stream
  + Added set_cerr_stream() and get_cerr_stream() to replace
    set_stream_err1(), set_stream_err2(), get_stream_err1(),
    get_stream_err2()
  + New configuration options ARMA_COUT_STREAM and
    ARMA_CERR_STREAM
- Adapt shared lib and baselibs.conf to updated shared object
  numbering.
* Wed Aug 16 2017 badshah400@gmail.com
- Update to version 7.960.1:
  + Undocumented bug fixes.
* Fri Aug  4 2017 badshah400@gmail.com
- Update to version 7.960.0:
  + Faster randn() when using OpenMP.
  + Faster gmm_diag class, for Gaussian mixture models with
    diagonal covariance matrices.
  + Added .sum_log_p() to the gmm_diag class.
  + Added gmm_full class, for Gaussian mixture models with full
    covariance matrices.
  + Expanded .each_slice() to optionally use OpenMP for
    multi-threaded execution.
- Drop %%%%check section entirely, this is not expected to work
  going forward. Also drop armadillo-tests.patch, which was meant
  for the tests in the %%%%check section.
* Wed Jun 21 2017 badshah400@gmail.com
- Update to version 7.950.1:
  + Expanded accu() and sum() to use OpenMP for processing
    expressions with computationally expensive element-wise
    functions.
  + Expanded trimatu() and trimatl() to allow specification of the
    diagonal which delineates the boundary of the triangular part.
* Mon May 15 2017 badshah400@gmail.com
- Update to version 7.900.1:
  + Expanded clamp() to handle cubes.
  + Computationally expensive element-wise functions (such as
    exp(), log(), cos(), etc) can now be automatically sped up via
    OpenMP; this requires a C++11/C++14 compiler with OpenMP 3.0+
    support.
- Rebase armadillo-tests.patch for updated version.
- Drop tests because upstream acknowledges some tests are intended
  to fail without ARPACK.
* Sat Feb 18 2017 badshah400@gmail.com
- Update to version 7.800.0:
  + Changed license to the permissve Apache License 2.0.
- Update License tag in specfile in keeping with upstream.
- Update package file list:
  + Include the license doc NOTICE.txt.
  + Additional documentation file: armadillo_joss_2016.pdf.
* Wed Feb  8 2017 badshah400@gmail.com
- Update to version 7.700.0:
  + Added polyfit() and polyval().
  + Added second form of log_det() to directly return the result
    as a complex number.
  + Added range() to statistics functions.
  + Expanded trimatu()/trimatl() and symmatu()/symmatl() to handle
    sparse matrices.
* Sun Dec 25 2016 badshah400@gmail.com
- Update to version 7.600.2:
  + Undocumented bug fixes.
* Mon Dec 19 2016 badshah400@gmail.com
- Update to version 7.600.1:
  + More accurate eigs_sym() and eigs_gen().
  + Expanded floor(), ceil(), round(), trunc(), sign() to handle
    sparse matrices.
  + Added arg(), atan2(), hypot().
- Drop armadillo-install-pkgconfig.patch: resolved upstream.
* Mon Nov 21 2016 badshah400@gmail.com
- Update to version 7.500.2:
  + Undocumented bug fixes.
* Mon Nov 14 2016 badshah400@gmail.com
- Update to version 7.500.1:
  + Undocumented bug fixes.
* Sat Oct 29 2016 badshah400@gmail.com
- Add armadillo-install-pkgconfig.patch: Generate and install a
  pkgconfig file (PATCH-FEATURE-OPENSUSE for now, but in
  discussions with upstream to have this included).
- Add armadillo-tests.patch: Generate tests/Makefile by
  configuring tests/Makefile.in using cmake so that the tests can
  be run before actually installing the library. Then, use a
  make check section to test the built library
  (PATCH-FEATURE-OPENSUSE for now, but in discussions with
  upstream to have this included).
* Mon Oct 24 2016 badshah400@gmail.com
- Update to version 7.500.0:
  + Expanded qz() to optionally specify ordering of the Schur
    form.
  + Expanded .each_slice() to support matrix multiplication.
* Wed Sep 28 2016 badshah400@gmail.com
- Update to version 7.400.3:
  + Undocumented bug fixes.
* Mon Aug 29 2016 badshah400@gmail.com
- Update to version 7.400.2:
  + Added expmat_sym(), logmat_sympd(), sqrtmat_sympd().
  + Added .replace().
* Fri Jul 29 2016 badshah400@gmail.com
- Update to version 7.300.1:
  + Undocumented bug fixes.
* Thu Jul 28 2016 badshah400@gmail.com
- Update to version 7.300.0:
  + Added index_min() and index_max() standalone functions.
  + Expanded .subvec() to accept size() arguments.
  + More robust handling of non-square matrices by lu().
* Sat Jul  2 2016 badshah400@gmail.com
- Update to version 7.200.2:
  + added .index_min() and .index_max().
  + expanded ind2sub() to handle vectors of indices.
  + expanded sub2ind() to handle matrix of subscripts.
  + expanded expmat(), logmat() and sqrtmat() to optionally return
    a bool indicating success faster handling of compound
    expressions by vectorise().
- Changes from Version 7.100.0:
  + added erf(), erfc(), lgamma().
  + added .head_slices() and .tail_slices() to subcube views.
  + spsolve() now requires SuperLU 5.2.
  + eigs_sym(), eigs_gen() and svds() now use a built-in
    reimplementation of ARPACK for real (non-complex) matrices;
    contributed by Yixuan Qiu.
- Source tarballs are now xz compressed.
- Update BuildRequires for superlu-devel: >= version 5.2 now
  required.
- Update shlib version (libarmadillo6 -> libarmadillo7) in spec
  file and baselibs.conf.
* Mon May 30 2016 jengelh@inai.de
- Drop ATLAS support, for libatlas itself is too much work and
  is getting dropped.
* Tue May  3 2016 badshah400@gmail.com
- Update to version 6.700.6:
  + Undocumented bug fixes.
* Wed Apr 27 2016 badshah400@gmail.com
- Update to version 6.700.5:
  + Undocumented bug fixes.
* Wed Apr 20 2016 badshah400@gmail.com
- Update to version 6.700.4:
  + Undocumented bug fixes.
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 6.700.3 (Catabolic Amalgamator Deluxe):
  + Added logmat() for calcuating the matrix logarithm
  + Added regspace() for generating vectors with regularly spaced
    elements
  + Added logspace() for generating vectors with logarithmically
    spaced elements
  + Added approx_equal() for determining approximate equality
  + Added trapz() for numerical integration
  + Expanded .save() and .load() with hdf5_binary_trans file type,
    to save/load data with columns transposed to rows
* Thu Mar 24 2016 badshah400@gmail.com
- Update to version 6.600.5 (Catabolic Amalgamator):
  + Expanded sum(), mean(), min(), max() to handle cubes.
  + Expanded Cube class to handle arbitrarily sized empty cubes
    (eg. 0x5x2).
  + Added shift() for circular shifts of elements.
  + Added sqrtmat() for finding the square root of a matrix.
  + Fix for gmm_diag when using Mahalanobis distance.
* Wed Feb 17 2016 badshah400@gmail.com
- Update to version 6.500.5:
  + Bug fixes (undocumented by upstream).
* Wed Jan 27 2016 badshah400@gmail.com
- Update to version 6.500.4 (Gourmet Electron Jumper):
  + Added conv2() for 2D convolution.
  + Added stand-alone kmeans() function for clustering data.
  + Added trunc().
  + Extended conv() to optionally provide central convolution.
  + Faster handling of multiply-and-accumulate by accu() when
    using Intel MKL, ATLAS or OpenBLAS.
* Tue Dec 15 2015 badshah400@gmail.com
- Update to version 6.400.2 (Flying Spaghetti Monster Deluxe):
  + Expanded each_col(), each_row() and each_slice() to handle
    C++11 lambda functions.
  + Added ind2sub() and sub2ind().
  + Fixes for corner cases in gmm_diag class.
* Sat Dec  5 2015 badshah400@gmail.com
- Update to version Version 6.300.2 (Flying Spaghetti Monster):
  + Expanded solve() to find approximate solutions for
    rank-deficient systems.
  + Faster handling of non-contiguous submatrix views in compound
    expressions.
  + Added .for_each() to Mat, Row, Col, Cube and field classes.
  + Added rcond() for estimating the reciprocal condition number.
  + Fixes for spsolve(), eigs_sym(), eigs_gen(), svds().
* Sun Nov 15 2015 badshah400@gmail.com
- Update to version 6.200.4:
  + Bug fixes (undocumented by upstream).
* Tue Nov 10 2015 badshah400@gmail.com
- Update to version 6.200.3:
  + Bug fixes (undocumented by upstream).
* Tue Nov  3 2015 badshah400@gmail.com
- Version 6.200.2 (Midnight Blue Deluxe):
  + Expanded diagmat() to handle non-square matrices and arbitrary
    diagonals.
  + Expanded trace() to handle non-square matrices.
  + Correction for datum::Z_0 constant.
* Sat Oct 24 2015 badshah400@gmail.com
- Update to version 6.100.1:
  + Bug fixes (undocumented by upstream).
* Thu Oct 15 2015 badshah400@gmail.com
- Version 6.100.0 (Midnight Blue):
  + Faster norm() and normalise() when using Intel MKL, ATLAS or
    OpenBLAS.
  + Added Schur decomposition: schur().
  + Stricter handling of matrix objects by hist() and histc().
  + Advanced constructors for using auxiliary memory now have the
    default of strict = false.
  + Cube class now delays allocation of .slice() related
    structures until needed.
  + Expanded join_slices() to handle joining cubes with matrices.
- Update shlib package name to libarmadillo6 in keeping with
  shlib version upgrade.
* Thu Sep  3 2015 badshah400@gmail.com
- Update to version 5.500.2:
  + Undocumented fixes.
- Changes from version 5.500.0 (Molotov Cocktail):
  + Expanded object constructors and generators to handle size()
    based specification of dimensions.
  + Faster handling of submatrix rows.
  + Faster clamp().
  + Fixes for handling sparse matrices.
* Wed Aug 19 2015 badshah400@gmail.com
- Update to version 5.400.2:
  + Undocumented fixes.
- Changes from version 5.400.0 (Plutocracy Incorporated Deluxe):
  + Added find_unique() for finding indices of unique values.
  + Added diff() for calculating differences between consecutive
    elements.
  + Added cumprod() for calculating cumulative product.
  + Added null() for finding the orthonormal basis of null space.
  + Expanded interp1() to handle repeated locations.
  + Expanded unique() to handle complex numbers.
  + Faster flipud().
  + Faster row-wise cumsum().
  + Fix for k-means clustering in gmm_diag class.
* Fri Aug  7 2015 badshah400@gmail.com
- Update to version 5.300.4:
  + Undocumented fixes.
- Changes from Version 5.300.0 (Plutocracy Incorporated):
  + Added generalised Schur decomposition: qz().
  + Added .has_inf() and .has_nan().
  + Expanded interp1() to handle out-of-domain locations.
  + Expanded sparse matrix class with .set_imag() and .set_real().
  + Expanded imag(), real() and conj() to handle sparse matrices.
  + Expanded diagmat(), reshape() and resize() to handle sparse
    matrices.
  + Faster sparse sum().
  + Faster row-wise sum(), mean(), min(), max().
  + Updated physical constants to NIST 2014 CODATA values.
  + Fixes for handling sparse submatrix views.
  + Armadillo can make use of GPUs by linking with NVIDIA NVBLAS
    (a GPU-accelerated implementation of BLAS),
    or by linking with AMD ACML (which can use GPUs via OpenCL).
* Wed Jun 24 2015 badshah400@gmail.com
- Update to version 5.200.2:
  + Bugfix in interp1().
* Mon May 25 2015 badshah400@gmail.com
- Update to version 5.200 (Boston Tea Smuggler):
  + Added orth() for finding the orthonormal basis of the range
    space of a matrix.
  + Expanded element initialisation to handle nested initialiser
    lists (C++11).
  + Workarounds for bugs in GCC, Intel and MSVC C++ compilers.
* Fri May 15 2015 badshah400@gmail.com
- Update to version 5.100.2:
  + Undocumented fixes.
- Update to version 5.100.1:
  + Undocumented fixes.
- Changes from version Version 5.100.0 (Ankle Biter Deluxe):
  + Added interp1() for 1D interpolation.
  + Added .is_sorted() for checking whether a vector or matrix
    has sorted elements.
  + Updated physical constants to NIST 2010 CODATA values.
* Thu Apr 16 2015 badshah400@gmail.com
- Update to version 5.000.1:
  + Fix an issue with C++11 support.
- Add superlu-devel as BuildRequires, and as Requires for
  armadillo.
* Mon Apr 13 2015 badshah400@gmail.com
- Update to version 5.000.0 (Ankle Biter):
  + Added spsolve() for solving sparse systems of linear
    equations.
  + Added svds() for singular value decomposition of sparse
    matrices.
  + Added nonzeros() for extracting non-zero values from matrices.
  + Added handling of diagonal views by sparse matrices.
  + Expanded repmat() to handle sparse matrices.
  + Expanded join_rows() and join_cols() to handle sparse
    matrices.
  + sort_index() and stable_sort_index() have been placed in the
    delayed operations framework for increased efficiency.
  + Use of 64 bit integers is automatically enabled when using a
    C++11 compiler.
  + Workaround for a bug in recent releases of Apple Xcode.
  + Workaround for a bug in LAPACK 3.5.
- New dependency: superlu >= 4.3.
- Updated shared library name to libarmadillo5 in track with
  upstream so name change.
* Sat Mar 21 2015 badshah400@gmail.com
- Update to version 4.650.4:
  + List of changes not documented upstream.
- Changes from version 4.650.2 and 4.650.3:
  + List of changes not documented upstream.
* Wed Feb 18 2015 badshah400@gmail.com
- Update to version 4.650.1:
  + List of changes not documented upstream.
- Changes from version 4.650 (Intravenous Caffeine Injector):
  + Added randg() for generating random values from gamma
    distributions (C++11 only).
  + Added .head_rows() and .tail_rows() to submatrix views.
  + Added .head_cols() and .tail_cols() to submatrix views.
  + Expanded eigs_sym() to optionally calculate eigenvalues with
    smallest/largest algebraic values fixes for handling of sparse
    matrices.
* Tue Jan 20 2015 badshah400@gmail.com
- Update to version 4.600.3:
  + List of changes not documented upstream.
- Changes from version 4.600.2:
  + List of changes not documented upstream.
* Sun Dec 28 2014 badshah400@gmail.com
- Update to version 4.600.1:
  + List of changes not documented upstream.
- Changes from version 4.600 (Off The Reservation):
  + Added .head() and .tail() to submatrix views
  + Faster matrix transposes within compound expressions
  + Faster accu() and norm() when compiling with
  - O3 -ffast-math -march=native (gcc and clang)
  + Workaround for a bug in GCC 4.4
* Sat Dec 27 2014 badshah400@gmail.com
- Update to version 4.550.4:
  + List of changes not documented upstream.
- Update to version 4.550.3:
  + List of changes not documented upstream.
* Tue Dec  2 2014 badshah400@gmail.com
- Update to version 4.550.2:
  + List of changes not documented upstream.
- Changes from version 4.550.1:
  + List of changes not documented upstream.
* Thu Nov 20 2014 badshah400@gmail.com
- Update to version 4.550 (Singapore Sling Deluxe):
  + Added matrix exponential function: expmat()
  + Faster .log_p() and .avg_log_p() functions in the gmm_diag
    class when compiling with OpenMP enabled
  + Faster handling of in-place addition/subtraction of
    expressions with an outer product.
* Mon Nov  3 2014 badshah400@gmail.com
- Update to version 4.500.1:
  + List of changes not documented upstream.
* Thu Oct 30 2014 badshah400@gmail.com
- Update to version 4.500.0:
  + Faster handling of complex vectors by norm()
  + Expanded chol() to optionally specify output matrix as upper
    or lower triangular
  + Better handling of non-finite values when saving matrices as
    text files.
* Mon Oct 13 2014 badshah400@gmail.com
- Update to version 4.450.4:
  + No list of changes documented upstream.
* Thu Oct  9 2014 badshah400@gmail.com
- Update to version 4.450.3:
  + No list of changes documented upstream.
* Fri Oct  3 2014 badshah400@gmail.com
- Update to version 4.450.2:
  + No list of changes documented upstream.
* Fri Sep 19 2014 badshah400@gmail.com
- Update to Version 4.450 (Spring Hill Fort):
  + Faster handling of matrix transposes within compound
    expressions
  + Expanded symmatu()/symmatl() to optionally disable taking the
    complex conjugate of elements
  + Expanded sort_index() to handle complex vectors
  + Expanded the gmm_diag class with functions to generate random
    samples
* Wed Aug 20 2014 badshah400@gmail.com
- Update to version 4.400.1:
  + No changes documented
- Changes from version 4.400 (Winter Shark Alley):
  + Faster handling of subvectors by dot()
  + Faster handling of aliasing by submatrix views
  + Expanded batch insertion constructors for sparse matrices to
    add values at repeated locations
  + Added clamp() for clamping values to be between lower and
    upper limits
  + Added gmm_diag class for statistical modelling using Gaussian
    Mixture Models (GMM);
  + Includes multi-threaded implementation of k-means and
    Expectation-Maximisation (EM) for parameter estimation.
* Wed Jul  2 2014 badshah400@gmail.com
- Update to Version 4.320   (Daintree Tea Raider)
  + Expanded eigs_sym() and eigs_gen() to use an optional
    tolerance parameter
  + Expanded eig_sym() to automatically fall back to standard
    decomposition method if divide-and-conquer fails
  + Automatic installer enables use of C++11 random number
    generator when using gcc 4.8.3+ in C++11 mode.
* Tue Jun  3 2014 badshah400@gmail.com
- Update to version 4.300.8:
  + List of changes not documented upstream.
* Wed May 21 2014 badshah400@gmail.com
- Update to version 4.300.5:
  + List of changes not documented upstream.
* Mon May 12 2014 badshah400@gmail.com
- Update to version 4.300.2:
  + Fix for detection of HDF5 library during automatic
    installation
  + Faster find()
* Sat May  3 2014 badshah400@gmail.com
- Update to version 4.300 (Medieval Cornea Scraper):
  + Faster find()
  + Added find_finite() and find_nonfinite() for finding indices
    of finite and non-finite elements
  + Expressions X=inv(A)*B*C and X=A.i()*B*C are automatically
    converted to X=solve(A,B*C)
  + Cmake-based installer enables use of C++11 random number
    generator when using gcc 4.9+ in C++11 mode
* Mon Apr  7 2014 badshah400@gmail.com
- Update to version 4.200.0 (Flintlock Swoop):
  + Faster transpose of sparse matrices
  + More efficient handling of aliasing during matrix
    multiplication
  + Faster inverse of matrices marked as diagonal.
* Sat Mar  8 2014 badshah400@gmail.com
- Update to version 4.100.2:
  + Fix for handling null vectors by normalise()
  + Fix for memory handling by sparse matrices.
* Fri Feb 28 2014 badshah400@gmail.com
- Update to version 4.100 (Dirt Cruiser)
  + added normalise() for normalising vectors to unit p-norm
  + extended the field class to handle 3D layout
  + extended eigs_sym() and eigs_gen() to obtain eigenvalues of
    various forms (eg. largest or smallest magnitude)
  + automatic SIMD vectorisation of elementary expressions
    (eg. matrix addition) when using Clang 3.4+ with -O3
    optimisation
  + faster handling of sparse submatrix views
  + workaround for a bug in LAPACK 3.4
- Changes from version 4.000.4:
  + fix for randi() generating out-of-interval values
  + fix for saving field objects
  + workaround for a bug in the Intel compiler
* Fri Jan 17 2014 badshah400@gmail.com
- Update to version 4.000.2:
  + List of changes not documented upstream
- Changes from version 4.000.1:
  + Fix for randi() generating out-of-interval values
  + Workaround for a bug in the Intel compiler
* Wed Jan  8 2014 badshah400@gmail.com
- Armadillo no longer depends on boost libraries, and requires
  arpack-ng instead; adapt build and run-time requirements
  appropriately
- Fix baselibs.conf for so name version update
- Add libatlas3 dependencies as recommended by upstream.
* Mon Jan  6 2014 badshah400@gmail.com
- Update to Version 4.000.0 (Feral Steamroller)
  + added eigen decompositions of sparse matrices: eigs_sym() and
    eigs_gen()
  + added eigen decomposition for pair of matrices: eig_pair()
  + added simpler forms of eig_gen()
  + added condition number of matrices: cond()
  + expanded find() to handle cubes
  + expanded subcube views to access elements specified in a vector
  + template argument for running_stat_vec expanded to accept
    vector types
  + more robust fast inverse of 4x4 matrices
  + faster divide-and-conquer decompositions are now used by
    default for eig_sym(), pinv(), princomp(), rank(), svd(),
    svd_econ()
  + the form inv(sympd(X)) no longer assumes that X is positive
    definite; use inv_sympd() instead
  + added MEX connector for interfacing Octave/Matlab with
    Armadillo matrices (contributed by George Yammine)
- Packaging changes:
  + SO version update to 4
  + Remove appropriate win64 examples instead of win32
* Tue Dec 10 2013 badshah400@gmail.com
- Update to version 3.930.1:
  + Changes not documented upstream.
* Tue Dec 10 2013 badshah400@gmail.com
- Update to version 3.930.0 (Dragon's Back):
  + added divide-and-conquer variant of svd_econ(), for faster SVD
  + added divide-and-conquer variant of pinv(), for faster
    pseudo-inverse
  + added element-wise variants of min() and max()
  + added size() based specifications of submatrix view sizes
  + added randi() for generating matrices with random integer
    values
  + added inplace_trans() for memory efficient in-place transposes
    (contributed by Alexandre Drouin)
  + added more intuitive specification of sort direction in sort()
    and sort_index()
  + added more intuitive specification of method in det(), .i(),
    inv() and solve()
  + added more precise timer for the wall_clock class when using
    C++11
* Sat Sep 28 2013 badshah400@gmail.com
- Update to version 3.920.1:
  + Fix ambigious overload
- Changes from version 3.920.0 (Agencia Nacional Stasi):
  + Faster .zeros()
  + Faster round(), exp2() and log2() when using C++11
  + Added signum function: sign()
  + Added move constructors when using C++11
  + Added 2D fast Fourier transform: fft2()
  + Added .tube() for easier extraction of vectors and subcubes
    from cubes
  + Added specification of a fill type during construction of Mat,
    Col, Row and Cube classes, eg. mat X(4, 5, fill::zeros).
* Wed Sep 11 2013 badshah400@gmail.com
- Update to version 3.910.1:
  + Minor fix for handling of complex matrices by braindead
    compilers (MSVC).
* Mon Aug 12 2013 badshah400@gmail.com
- Update to version 3.910.0 (Pyrenees):
  + Faster multiplication of a matrix with a transpose of itself,
    ie. X*X.t() and X.t()*X
  + Added vectorise() for reshaping matrices into vectors
  + Added all() and any() for indicating presence of elements
    satisfying a relational condition
* Wed Jul 31 2013 dmitry_r@opensuse.org
- Update to version 3.900.7
  * minor fix for inplace reshape()
  * minor corrections for compilation issues under GCC 4.8+
* Wed Jun 26 2013 badshah400@gmail.com
- Update to version 3.900.6:
  + No list of changes documented by upstream for 3.900.6 and
    3.900.5.
* Thu Jun 13 2013 badshah400@gmail.com
- Update to version 3.900.4:
  + Minor corrections for compilation issues under GCC 4.8+
- Changes from version 3.900.1, 3.900.2 and 3.900.3 not
  documented by upstream.
* Wed Jun  5 2013 badshah400@gmail.com
- Update to version 3.900.0:
  + Added automatic SSE2 vectorisation of elementary expressions
    (eg. matrix addition) when using GCC 4.7+ with -O3
    optimisation
  + Added support for saving & loading of cubes in HDF5 format
  + Faster median()
  + Faster handling of compound expressions with transposes of
    submatrix rows
  + Faster handling of compound expressions with transposes of
    complex vectors.
* Wed May 22 2013 badshah400@gmail.com
- Update to version 3.820.1:
  + Added detection of the OpenBLAS library during installation,
    which provides high-speed matrix multiplication
* Sun May 12 2013 badshah400@gmail.com
- Update to version 3.820.0 (Mt Cootha):
  + Faster as_scalar() for compound expressions
  + Faster transpose of small vectors
  + Faster matrix-vector product for small vectors
  + Faster multiplication of small fixed size matrices.
* Fri Apr 19 2013 badshah400@gmail.com
- Update to version 3.810.0 (Newell Highway):
  + Added fast Fourier transform: fft()
  + Added handling of .imbue() and .transform() by submatrices and
    subcubes
  + Added batch insertion constructors for sparse matrices
  + Minor fix for multiplication of complex sparse matrices
  + Better detection of recent Intel MKL versions during
    installation.
* Mon Mar 25 2013 badshah400@gmail.com
- Update to version 3.800.2:
  * minor fix for installation on Mac OS X systems
* Tue Mar 12 2013 dmitry_r@opensuse.org
- Update to version 3.800.1
  * workaround for a bug in ATLAS 3.8 on 64 bit systems
  * faster matrix-vector multiply for small matrices
* Fri Mar  1 2013 dmitry_r@opensuse.org
- Update to version 3.800.0
  * Armadillo is now licensed using the Mozilla Public License 2.0
  * added .imbue() for filling a matrix/cube with values provided
    by a functor or lambda expression
  * added .swap() for swapping contents with another matrix
  * added .transform() for transforming a matrix/cube using a
    functor or lambda expression
  * added round() for rounding matrix elements towards nearest integer
  * faster find()
  * fixes for handling non-square matrices by qr() and qr_econ()
  * minor fixes for handling empty matrices
  * reduction of pedantic compiler warnings
* Wed Feb 20 2013 dmitry_r@opensuse.org
- Update to version 3.6.3
  * faster find()
  * minor fix for non-contiguous submatrix views to handle
    empty vectors of indices
* Tue Jan 29 2013 dmitry_r@opensuse.org
- Update to version 3.6.2
  * faster determinant for matrices marked as diagonal or triangular
  * more fine-grained handling of 64 bit integers
* Fri Dec 21 2012 dmitry_r@opensuse.org
- Update to version 3.6.1
  Changes in 3.6.1
  * faster trace()
  * fix for handling sparse matrices by dot()
  * fixes for interactions between sparse and dense matrices
  Changes in 3.6.0
  * faster handling of compound expressions with submatrices
    and subcubes
  * added support for loading matrices as text files with
    NaN and Inf elements
  * added stable_sort_index(), which preserves the relative
    order of elements with equivalent values
  * added handling of sparse matrices by mean(), var(),
    norm(), abs(), square(), sqrt()
  * added saving and loading of sparse matrices in
    arma_binary format
* Thu Nov 22 2012 cgiboudeaux@gmx.com
- Update to 3.4.4
  * Fix for handling complex numbers by sparse matrices
  * Fix for minor memory leak by sparse matrices
* Sun Oct  7 2012 badshah400@gmail.com
- Update to version 3.4.3:
  + Fix for aliasing issue in diagmat()
  + Fix for speye() signature
  + Fixes for handling empty sparse matrices
  + Minor fixes for handling sparse submatrix views
  + Minor speedups for sparse matrices
  + Workaround for a bug in the Mac OS X accelerate framework
  + Added documentation for saving & loading matrices in HDF5
    format
  + Faster dot() and cdot() for complex numbers.
* Wed Sep 26 2012 badshah400@gmail.com
- Update to version 3.4.2:
  + Minor fixes for handling sparse submatrix views
  + Minor speedups for sparse matrices.
* Sat Sep 22 2012 badshah400@gmail.com
- Update to version 3.4.1:
  +  Workaround for a bug in the Mac OS X accelerate framework
  +  Fixes for handling empty sparse matrices
  +  Added documentation for saving & loading matrices in HDF5
    format
  +  Faster dot() and cdot() for complex numbers.
* Fri Sep  7 2012 badshah400@gmail.com
- Update to version 3.4.0 (Ku De Ta):
  + Faster .randn().
* Sat Sep  1 2012 badshah400@gmail.com
- Update to version 3.3.91 (3.4 Beta 1):
  + Faster singular value decomposition via "divide and conquer"
    algorithm
  + Added economical QR decomposition: qr_econ()
  + Added .each_col() & .each_row() for vector operations repeated
    on each column or row
  + Added preliminary support for sparse matrices.
* Wed Jul 11 2012 badshah400@gmail.com
- Update to version 3.2.4:
  + Workaround for a regression (bug) in GCC 4.7.0 and 4.7.1.
* Fri Jun 29 2012 badshah400@gmail.com
- Update to version 3.2.3:
  + Minor correction for declaration of fixed size vectors and
    matrices.
* Fri Jun 22 2012 scorot@free.fr
- fix build on SLE 11
* Thu May 31 2012 badshah400@gmail.com
- Update to version 3.2.2:
  + Better detection of ATLAS on Fedora and Red Hat systems
  + Minor fix for compiling without debugging enabled (aka release
    mode).
* Tue May 29 2012 badshah400@gmail.com
- Update to version 3.2.1:
  + Minor fix for compiling without debugging enabled (aka release
    mode).
* Fri May 18 2012 badshah400@gmail.com
- Update to version 3.2.0:
  + Faster eigen decomposition via "divide and conquer" algorithm
  + Faster transpose of vectors and compound expressions
  + Faster handling of diagonal views
  + Faster handling of tiny fixed size vectors (≤ 4 elements)
  + Added unique(), for finding unique elements of a matrix.
* Thu May  3 2012 badshah400@gmail.com
- Update to version 3.0.3:
  + Fixes for inplace transpose of complex number matrices
  + Fixes for complex number version of svd_econ()
  + Fixes for potential aliasing issues with submatrix views.
* Sun Apr 29 2012 badshah400@gmail.com
- Update to version 3.0.2:
  + Fixes for handling diagonal matrices
  + Fixes for compilation errors
  + Fixes for potential aliasing issues.
* Fri Apr 13 2012 badshah400@gmail.com
- Update to version 3.0.1:
  + Fixes for compilation errors
  + Fixes for potential aliasing issues.
* Mon Apr  9 2012 badshah400@gmail.com
- Update to version 3.0.0:
  + Added non-contiguous submatrix views
  + Added shorthand for inverse: .i()
  + Added hist() and histc()
  + Faster repmat()
  + Faster handling of submatrix views with one row or column
  + Faster generation of random numbers
  + Faster element access in fixed size matrices
  + Better detection of vector expressions by various functions
  + Expressions X=A.i()*B and X=inv(A)*B are automatically
    converted to X=solve(A,B)
- Rename shared library package to libarmadillo3 in keeping with
  .so file number change
- Update baselibs.conf in keeping with changes to the shared
  library package name.
* Wed Apr  4 2012 badshah400@gmail.com
- Update to version 2.4.4:
  + Fixes for qr() and syl()
  + More portable wall_clock class
  + Faster relational operators on submatrices.
- Update lapack dependencies in keeping with lapack changes in
  devel project to fix builds on openSUSE 12.1 and 11.4.
* Tue Feb  7 2012 badshah400@gmail.com
- Update to version 2.4.3 (no summary of changes documented
  upstream)
* Mon Dec 12 2011 badshah400@gmail.com
- Update to version 2.4.2:
  + Clarified documentation for .reshape()
  + Fix for handling of empty matrices by .resize()
* Mon Dec  5 2011 badshah400@gmail.com
- Update to version 2.4.1:
  + Added .resize()
  + Fix for vector initialisation
* Mon Dec  5 2011 badshah400@gmail.com
- Update to version 2.4.0:
  + Added shorter forms of transposes: .t() and .st()
  + Added optional use of 64 bit indices, allowing matrices to
    have more than 4 billion elements
  + Added experimental support for C++11 initialiser lists
  + Faster pinv()
  + Faster inplace transpose
  + Faster handling of expressions with diagonal views
  + Fixes for handling expressions with aliasing and submatrices
  + Fixes for linking on Ubuntu and Debian systems
  + Fixes for inconsistencies in interactions between matrices
    and cubes
  + Refactored code to eliminate warnings when using the Clang
    C++ compiler
  + .print_trans() and .raw_print_trans() are deprecated.
- Spec file cleanups:
  + Use upstream provided tarballs (in tar.gz format) instead of
    recompressing to tar.bz2
  + Modify License tag in confomity with spdx.org specifications
* Tue Nov 22 2011 badshah400@gmail.com
- Update to version 2.3.91 (2.4 beta 1):
  + Added shorter forms of transposes: .t() and .st()
  + Added optional use of 64 bit indices, allowing matrices to
    have more than 4 billion elements
  + Added experimental support for C++11 initialiser lists
  + Faster pinv()
  + Faster inplace transpose
  + Bugfixes for handling expressions with aliasing and
    submatrices
  + Refactored code to eliminate warnings when using the Clang
    C++ compiler
  + .print_trans() and .raw_print_trans() are deprecated
* Tue Nov 15 2011 badshah400@gmail.com
- Update to version 2.2.5 (bug-fix release; no summary of changes
  documented upstream)
* Wed Oct 19 2011 badshah400@gmail.com
- Update to version 2.2.4 (bug-fix release; no summary of changes
  documented upstream)
* Sun Sep 25 2011 jengelh@medozas.de
- Remove forbidden Obsoletes (cf. shlib guide)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Implement baselibs for package
* Sat Aug 27 2011 badshah400@gmail.com
- Update to version 2.2.3
  + Bug fix for speed issue in as_scalar()
* Tue Aug 23 2011 badshah400@gmail.com
- Update to version 2.2.2 (no summary of changes documented by
  upstream)
* Tue Aug  2 2011 badshah400@gmail.com
- Update to version 2.2.1
  + Faster multiplication of small matrices
  + Faster trans()
  + Faster handling of submatrices by norm()
  + Added economical singular value decomposition: svd_thin()
  + Added circ_toeplitz()
  + Added .is_colvec() & .is_rowvec()
  + Fixes for handling of complex numbers by cov(), cor(),
    running_stat_vec
* Sat Jul 16 2011 badshah400@gmail.com
- Update to version 2.0.2
  + Various bug fixes
- Changes from version 2.0.0
  + Faster multiplication of tiny matrices
  + Faster compound expressions containing submatrices
  + Faster inverse of symmetric positive definite matrices
  + Faster element access for fixed size matrices
  + Added handling of arbitrarily sized empty matrices (eg. 5x0)
  + Added loading & saving of matrices as CSV text files
  + Added .count() member function to running_stat and
    running_stat_vec
  + Added syl(), strans(), symmatu()/symmatl()
  + Added submatrices of submatrices
  + det(), inv() and solve() can be forced to use more precise
    algorithms for tiny matrices
  + htrans() has been deprecated; use trans() instead
  + API change: trans() now takes the complex conjugate when
    transposing a complex matrix
  + API change: .is_vec() now outputs true for empty vectors (eg. 0x1)
  + API change: forms of chol(), eig_sym(), eig_gen(), inv(),
    lu(), pinv(), princomp(), qr(), solve(), svd(), syl() that
    do not return a bool indicating success now throw
    std::runtime_error exceptions when failures are detected
  + API change: princomp_cov() has been removed;
    eig_sym() in conjunction with cov() can be used instead
  + API change: set_log_stream() & get_log_stream() have been
    replaced by set_stream_err1() & get_stream_err1()
  + Rename shared library package to libarmadillo2; obsoletes
    libarmadillo1
* Mon Apr 18 2011 badshah400@gmail.com
- Update to version 1.2.0
  + Added ability to use Blas & Lapack libraries with capitalised
    function names
  + Reduction of pedantic compiler warnings
* Fri Apr  1 2011 badshah400@gmail.com
- Update to version 1.1.92:
  + Bugfix in function cor()
  + Automatic installation now requires CMake >= 2.6
- Add licenses to libarmadillo package
* Wed Mar 23 2011 badshah400@gmail.com
- Spec file cleanup
* Wed Mar 23 2011 badshah400@gmail.com
- Initial package (following spec file from fedora)
